@@ -148,6 +148,8 @@ class Element(with_metaclass(junitxml, object)):
     """Base class for all Junit XML elements."""
 
     def __init__(self, name=None):
+        if not name:
+            name = self._tag
         self._elem = etree.Element(name)
 
     def __hash__(self):
@@ -170,6 +172,12 @@ class Element(with_metaclass(junitxml, object)):
         """
         self._elem.append(sub_elem._elem)
 
+    def extend(self, sub_elems):
+        """Adds elements subelement to the end of this elements internal
+        list of subelements.
+        """
+        self._elem.extend((sub_elem._elem for sub_elem in sub_elems))
+
     @classmethod
     def fromstring(cls, text):
         """Construct Junit objects from a XML string."""
@@ -468,6 +476,11 @@ class TestSuite(Element):
         self.append(testcase)
         self.update_statistics()
 
+    def add_testcases(self, testcases):
+        """Adds test cases to the suite."""
+        self.extend(testcases)
+        self.update_statistics()
+
     def _add_testcase_no_update_stats(self, testcase):
         """
         Adds a testcase to the suite (without updating stats).
