@@ -22,6 +22,7 @@ from junitparser import (
     Properties,
     IntAttr,
     FloatAttr,
+    Element,
 )
 
 try:
@@ -96,7 +97,7 @@ class Test_JunitXml(unittest.TestCase):
 
     def test_fromstring_numbers_locale_insensitive(self):
         "Case relies on that LC_ALL is set in the console."
-        for loc in ['', 'en_US.UTF-8', 'de_DE.UTF-8']:
+        for loc in ["", "en_US.UTF-8", "de_DE.UTF-8"]:
             old_locale = locale.getlocale(locale.LC_NUMERIC)
             try:
                 locale.setlocale(locale.LC_NUMERIC, loc)
@@ -419,6 +420,22 @@ class Test_TestSuite(unittest.TestCase):
         suite2.add_property("name2", "value2")
         self.assertNotEqual(suite, suite2)
 
+    def test_add_cases(self):
+        suite = TestSuite()
+        self.assertEqual(suite.tests, 0)
+        case1 = TestCase()
+        case2 = TestCase()
+        case2.result = [Failure()]
+        case3 = TestCase()
+        case3.result = [Error()]
+        case4 = TestCase()
+        case4.result = [Skipped()]
+        suite.add_testcases([case1, case2, case3, case4])
+        suite.update_statistics()
+        self.assertEqual(suite.tests, 4)
+        self.assertEqual(suite.failures, 1)
+        self.assertEqual(suite.errors, 1)
+        self.assertEqual(suite.skipped, 1)
 
 class Test_TestCase(unittest.TestCase):
     def test_case_fromstring(self):
@@ -562,6 +579,21 @@ class Test_TestCase(unittest.TestCase):
             res1.tostring(), [b'<failure message="A" />', b'<failure message="A"/>']
         )
 
+    def test_add_child_element(self):
+        class CustomElement(Element):
+            _tag = "custom"
+            foo = Attr()
+            bar = Attr()
+
+        testcase = TestCase()
+        custom = CustomElement()
+        testcase.append(custom)
+
+        self.assertIn(
+            testcase.tostring(),
+            [b"<testcase><custom /></testcase>", b"<testcase><custom/></testcase>"],
+        )
+
 
 class Test_Properties(unittest.TestCase):
     def test_property_repr1(self):
